@@ -4,12 +4,13 @@ __all__ = [
     'PasswordRequiredError', 'StartServiceError', 'FatalPairingError', 'NoDeviceConnectedError', 'MuxException',
     'MuxVersionError', 'ArgumentError', 'AfcException', 'AfcFileNotFoundError', 'DvtException', 'DvtDirListError',
     'NotMountedError', 'AlreadyMountedError', 'UnsupportedCommandError', 'ExtractingStackshotError',
-    'ConnectionTerminatedError', 'WirError', 'WebInspectorNotEnabled', 'RemoteAutomationNotEnabled',
-    'ArbitrationError', 'NoSuchBuildIdentityError', 'InternalError', 'DeveloperModeIsNotEnabledError',
-    'DeviceAlreadyInUseError', 'LockdownError', 'PairingDialogResponsePendingError', 'UserDeniedPairingError',
-    'InvalidHostIDError', 'SetProhibitedError', 'MissingValueError', 'PasscodeRequiredError', 'AmfiError',
-    'DeviceHasPasscodeSetError', 'NotificationTimeoutError', 'DeveloperModeError', 'ProfileError',
-    'UsbmuxConnectionError', 'IRecvError', 'IRecvNoDeviceConnectedError',
+    'ConnectionTerminatedError', 'WirError', 'WebInspectorNotEnabledError', 'RemoteAutomationNotEnabledError',
+    'ArbitrationError', 'InternalError', 'DeveloperModeIsNotEnabledError', 'DeviceAlreadyInUseError', 'LockdownError',
+    'PairingDialogResponsePendingError', 'UserDeniedPairingError', 'InvalidHostIDError', 'SetProhibitedError',
+    'MissingValueError', 'PasscodeRequiredError', 'AmfiError', 'DeviceHasPasscodeSetError', 'NotificationTimeoutError',
+    'DeveloperModeError', 'ProfileError', 'UsbmuxConnectionError', 'IRecvError', 'IRecvNoDeviceConnectedError',
+    'NoDeviceSelectedError', 'MessageNotSupportedError', 'InvalidServiceError', 'InspectorEvaluateError',
+    'LaunchingApplicationError',
 ]
 
 
@@ -127,12 +128,12 @@ class ConnectionTerminatedError(PyMobileDevice3Exception):
     pass
 
 
-class WebInspectorNotEnabled(PyMobileDevice3Exception):
+class WebInspectorNotEnabledError(PyMobileDevice3Exception):
     """ Raise when Web Inspector is not enabled. """
     pass
 
 
-class RemoteAutomationNotEnabled(PyMobileDevice3Exception):
+class RemoteAutomationNotEnabledError(PyMobileDevice3Exception):
     """ Raise when Web Inspector remote automation is not enabled. """
     pass
 
@@ -168,11 +169,6 @@ class DeviceAlreadyInUseError(ArbitrationError):
         return self.args[0].get('result')
 
 
-class NoSuchBuildIdentityError(PyMobileDevice3Exception):
-    """ Failed to find BuildIdentity with desired parameters """
-    pass
-
-
 class DeveloperModeIsNotEnabledError(PyMobileDevice3Exception):
     """ Raise when mounting failed because developer mode is not enabled. """
     pass
@@ -242,3 +238,23 @@ class IRecvError(PyMobileDevice3Exception):
 
 class IRecvNoDeviceConnectedError(IRecvError):
     pass
+
+
+class NoDeviceSelectedError(PyMobileDevice3Exception):
+    pass
+
+
+class MessageNotSupportedError(PyMobileDevice3Exception):
+    pass
+
+
+class InvalidServiceError(LockdownError):
+    pass
+
+
+class InspectorEvaluateError(PyMobileDevice3Exception):
+    pass
+
+
+class LaunchingApplicationError(PyMobileDevice3Exception):
+    pass
