@@ -63,19 +63,19 @@ def decode_message_format(message) -> str:
         elif 'decimal' in type_:
             uint64 = struct.unpack('<Q', data.ljust(8, b'\x00'))[0]
             s += str(uint64)
-        elif type_ == 'data':
-            s += b''.join(data).hex()
-        elif type_ == 'uuid':
-            s += b''.join(data).hex()
+        elif type_ in ('data', 'uuid'):
+            if data is not None:
+                s += b''.join(data).hex()
         else:
-            s += data
+            # by default, make sure the data can be concatenated
+            s += str(data)
     return s
 
 
 class ActivityTraceTap(Tap):
     IDENTIFIER = 'com.apple.instruments.server.services.activitytracetap'
 
-    def __init__(self, dvt):
+    def __init__(self, dvt, enable_http_archive_logging=False):
         # TODO:
         #   reverse: [DTOSLogLoader _handleRecord:], DTTableRowEncoder::*
         #   to understand each row's structure.
@@ -90,7 +90,9 @@ class ActivityTraceTap(Tap):
             'predicate': '(messageType == info OR messageType == debug OR messageType == default OR '
                          'messageType == error OR messageType == fault)',
             'signpostsAndLogs': 1,
-            'targetPID': -1,  # all Process
+            'trackPidToExecNameMapping': True,
+            'enableHTTPArchiveLogging': enable_http_archive_logging,
+            'targetPID': -3,  # all Process
             'trackExpiredPIDs': 1,
             'ur': 500,
         }
@@ -106,7 +108,7 @@ class ActivityTraceTap(Tap):
         message = b''
         while message.startswith(b'bplist') or len(message) == 0:
             # ignore heartbeat messages
-            message = self._channel.receive_message()
+            message = self.channel.receive_message()
         self._set_current_message(message)
 
     def _set_current_message(self, message):
@@ -219,7 +221,7 @@ class ActivityTraceTap(Tap):
 
         Message = dataclasses.make_dataclass('message', [c.replace('-', '_') for c in columns])
         message = Message(*row)
-        message.process = struct.unpack('<I', message.process[0].ljust(4, b'\x00'))[0]
+        message.process = 0 if message.process is None else struct.unpack('<I', message.process[0].ljust(4, b'\x00'))[0]
         message.thread = struct.unpack('<I', message.thread[0].ljust(4, b'\x00'))[0]
 
         string_fields = ('message_type', 'format_string', 'subsystem', 'category', 'sender_image_path',
